@@ -5,15 +5,15 @@ from datadog.api.resources import (
     AddableAPISubResource,
     DeletableAPISubResource,
     ListableAPISubResource,
-    UpdatableAPISubResource
+    UpdatableAPISubResource,
 )
 
 
-class DashboardListV2(ListableAPISubResource, AddableAPISubResource,
-                      UpdatableAPISubResource, DeletableAPISubResource):
+class DashboardListV2(ListableAPISubResource, AddableAPISubResource, UpdatableAPISubResource, DeletableAPISubResource):
     """
     A wrapper around Dashboard List HTTP API.
     """
-    _resource_name = 'dashboard/lists/manual'
-    _sub_resource_name = 'dashboards'
-    _api_version = 'v2'
+
+    _resource_name = "dashboard/lists/manual"
+    _sub_resource_name = "dashboards"
+    _api_version = "v2"
