@@ -8,7 +8,8 @@ class Infrastructure(SearchableAPIResource):
     """
     A wrapper around Infrastructure HTTP API.
     """
-    _resource_name = 'search'
+
+    _resource_name = "search"
 
     @classmethod
     def search(cls, **params):
@@ -21,8 +22,7 @@ class Infrastructure(SearchableAPIResource):
         :returns: Dictionary representing the API's JSON response
         """
         # Deprecate the hosts search param
-        query = params.get('q', '').split(':')
-        if len(query) > 1 and query[0] == 'hosts':
-            print("[DEPRECATION] Infrastructure.search() is deprecated for ",
-                  "hosts. Use `Hosts.search` instead.")
+        query = params.get("q", "").split(":")
+        if len(query) > 1 and query[0] == "hosts":
+            print("[DEPRECATION] Infrastructure.search() is deprecated for ", "hosts. Use `Hosts.search` instead.")
         return super(Infrastructure, cls)._search(**params)
