@@ -24,13 +24,13 @@ from datadog.dogstatsd.route import get_default_route
 from datadog.util.compat import text
 from datadog.util.format import normalize_tags
 from datadog.version import __version__
-from typing import Optional, List, Text
+from typing import Optional, List, Text, Union
 
 # Logging
-log = logging.getLogger('datadog.dogstatsd')
+log = logging.getLogger("datadog.dogstatsd")
 
 # Default config
-DEFAULT_HOST = 'localhost'
+DEFAULT_HOST = "localhost"
 DEFAULT_PORT = 8125
 
 # Tag name of entity_id
@@ -42,10 +42,10 @@ UDS_OPTIMAL_PAYLOAD_LENGTH = 8192
 
 # Mapping of each "DD_" prefixed environment variable to a specific tag name
 DD_ENV_TAGS_MAPPING = {
-    'DD_ENTITY_ID': ENTITY_ID_TAG_NAME,
-    'DD_ENV': 'env',
-    'DD_SERVICE': 'service',
-    'DD_VERSION': 'version',
+    "DD_ENTITY_ID": ENTITY_ID_TAG_NAME,
+    "DD_ENV": "env",
+    "DD_SERVICE": "service",
+    "DD_VERSION": "version",
 }
 
 # Telemetry minimum flush interval in seconds
@@ -57,20 +57,21 @@ class DogStatsd(object):
 
     def __init__(
         self,
-        host=DEFAULT_HOST,              # type: Text
-        port=DEFAULT_PORT,              # type: int
-        max_buffer_size=None,           # type: None
-        namespace=None,                 # type: Optional[Text]
-        constant_tags=None,             # type: Optional[List[str]]
-        use_ms=False,                   # type: bool
-        use_default_route=False,        # type: bool
-        socket_path=None,               # type: Optional[Text]
-        default_sample_rate=1,          # type: float
-        disable_telemetry=False,        # type: bool
-        telemetry_min_flush_interval=(
-            DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL
-        ),                              # type: int
-        max_buffer_len=0                # type: int
+        host=DEFAULT_HOST,  # type: Text
+        port=DEFAULT_PORT,  # type: int
+        max_buffer_size=None,  # type: None
+        namespace=None,  # type: Optional[Text]
+        constant_tags=None,  # type: Optional[List[str]]
+        use_ms=False,  # type: bool
+        use_default_route=False,  # type: bool
+        socket_path=None,  # type: Optional[Text]
+        default_sample_rate=1,  # type: float
+        disable_telemetry=False,  # type: bool
+        telemetry_min_flush_interval=(DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL),  # type: int
+        telemetry_host=None,  # type: Text
+        telemetry_port=None,  # type: Union[str, int]
+        telemetry_socket_path=None,  # type: Text
+        max_buffer_len=0,  # type: int
     ):  # type: (...) -> None
         """
         Initialize a DogStatsd object.
@@ -106,6 +107,14 @@ class DogStatsd(object):
         :envvar DD_DOGSTATSD_DISABLE: Disable any statsd metric collection (default False)
         :type DD_DOGSTATSD_DISABLE: boolean
 
+        :envvar DD_TELEMETRY_HOST: the host for the dogstatsd server we wish to submit
+        telemetry stats to. If set, it overrides default value.
+        :type DD_TELEMETRY_HOST: string
+
+        :envvar DD_TELEMETRY_PORT: the port for the dogstatsd server we wish to submit
+        telemetry stats to. If set, it overrides default value.
+        :type DD_TELEMETRY_PORT: integer
+
         :param host: the host of the DogStatsd server.
         :type host: string
 
@@ -139,6 +148,26 @@ class DogStatsd(object):
         if sending metrics in batch. If not specified it will be adjusted to a optimal value
         depending on the connection type.
         :type max_buffer_len: integer
+
+        :param disable_telemetry: Should client telemetry be disabled
+        :type disable_telemetry: boolean
+
+        :param telemetry_min_flush_interval: Minimum flush interval for telemetry in seconds
+        :type telemetry_min_flush_interval: integer
+
+        :param telemetry_host: the host for the dogstatsd server we wish to submit
+        telemetry stats to. Optional. If telemetry is enabled and this is not specified
+        the default host will be used.
+        :type host: string
+
+        :param telemetry_port: the port for the dogstatsd server we wish to submit
+        telemetry stats to. Optional. If telemetry is enabled and this is not specified
+        the default host will be used.
+        :type port: integer
+
+        :param telemetry_socket_path: Submit client telemetry to dogstatsd through a UNIX
+        socket instead of UDP. If set, disables UDP transmission (Linux only)
+        :type telemetry_socket_path: string
         """
 
         self.lock = Lock()
@@ -148,20 +177,28 @@ class DogStatsd(object):
             log.warning("The parameter max_buffer_size is now deprecated and is not used anymore")
 
         # Check host and port env vars
-        agent_host = os.environ.get('DD_AGENT_HOST')
+        agent_host = os.environ.get("DD_AGENT_HOST")
         if agent_host and host == DEFAULT_HOST:
             host = agent_host
 
-        dogstatsd_port = os.environ.get('DD_DOGSTATSD_PORT')
+        dogstatsd_port = os.environ.get("DD_DOGSTATSD_PORT")
         if dogstatsd_port and port == DEFAULT_PORT:
             try:
                 port = int(dogstatsd_port)
             except ValueError:
-                log.warning("Port number provided in DD_DOGSTATSD_PORT env var is not an integer: \
-                %s, using %s as port number", dogstatsd_port, port)
+                log.warning(
+                    "Port number provided in DD_DOGSTATSD_PORT env var is not an integer: \
+                %s, using %s as port number",
+                    dogstatsd_port,
+                    port,
+                )
+
+        # Assuming environment variables always override
+        telemetry_host = os.environ.get("DD_TELEMETRY_HOST", telemetry_host)
+        telemetry_port = os.environ.get("DD_TELEMETRY_PORT", telemetry_port) or port
 
         # Check enabled
-        if os.environ.get('DD_DOGSTATSD_DISABLE') not in {'True', 'true', 'yes', '1'}:
+        if os.environ.get("DD_DOGSTATSD_DISABLE") not in {"True", "true", "yes", "1"}:
             self._enabled = True
         else:
             self._enabled = False
@@ -183,18 +220,27 @@ class DogStatsd(object):
             if not self._max_payload_size:
                 self._max_payload_size = UDP_OPTIMAL_PAYLOAD_LENGTH
 
+        self.telemetry_socket_path = telemetry_socket_path
+        self.telemetry_host = None
+        self.telemetry_port = None
+        if not telemetry_socket_path and telemetry_host:
+            self.telemetry_socket_path = None
+            self.telemetry_host = self.resolve_host(telemetry_host, use_default_route)
+            self.telemetry_port = int(telemetry_port)
+
         # Socket
         self.socket = None
+        self.telemetry_socket = None
         self._send = self._send_to_server
-        self.encoding = 'utf-8'
+        self.encoding = "utf-8"
 
         # Options
-        env_tags = [tag for tag in os.environ.get('DATADOG_TAGS', '').split(',') if tag]
+        env_tags = [tag for tag in os.environ.get("DATADOG_TAGS", "").split(",") if tag]
         # Inject values of DD_* environment variables as global tags.
         for var, tag_name in DD_ENV_TAGS_MAPPING.items():
-            value = os.environ.get(var, '')
+            value = os.environ.get(var, "")
             if value:
-                env_tags.append('{name}:{value}'.format(name=tag_name, value=value))
+                env_tags.append("{name}:{value}".format(name=tag_name, value=value))
         if constant_tags is None:
             constant_tags = []
         self.constant_tags = constant_tags + env_tags
@@ -206,10 +252,10 @@ class DogStatsd(object):
 
         # init telemetry version
         self._client_tags = [
-                "client:py",
-                "client_version:{}".format(__version__),
-                "client_transport:{}".format(transport),
-                ]
+            "client:py",
+            "client_version:{}".format(__version__),
+            "client_transport:{}".format(transport),
+        ]
         self._reset_telemetry()
         self._telemetry_flush_interval = telemetry_min_flush_interval
         self._telemetry = not disable_telemetry
@@ -220,6 +266,9 @@ class DogStatsd(object):
     def enable_telemetry(self):
         self._telemetry = True
 
+    def _dedicated_telemetry_destination(self):
+        return bool(self.telemetry_socket_path or self.telemetry_host)
+
     def __enter__(self):
         self.open_buffer()
         return self
@@ -232,17 +281,17 @@ class DogStatsd(object):
         """
         Resolve the DogStatsd host.
 
-        Args:
-            host (string): host
-            use_default_route (bool): use the system default route as host
-                (overrides the `host` parameter)
+        :param host: host
+        :type host: string
+        :param use_default_route: use the system default route as host (overrides the `host` parameter)
+        :type use_default_route: bool
         """
         if not use_default_route:
             return host
 
         return get_default_route()
 
-    def get_socket(self):
+    def get_socket(self, telemetry=False):
         """
         Return a connected socket.
 
@@ -250,20 +299,36 @@ class DogStatsd(object):
         avoid bad thread race conditions.
         """
         with self.lock:
-            if not self.socket:
-                if self.socket_path is not None:
-                    sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
-                    sock.setblocking(0)
-                    sock.connect(self.socket_path)
-                    self.socket = sock
-                else:
-                    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-                    sock.setblocking(0)
-                    sock.connect((self.host, self.port))
-                    self.socket = sock
+            if telemetry and self._dedicated_telemetry_destination():
+                if not self.telemetry_socket:
+                    if self.telemetry_socket_path is not None:
+                        self.telemetry_socket = self._get_uds_socket(self.telemetry_socket_path)
+                    else:
+                        self.telemetry_socket = self._get_udp_socket_socket(self.telemetry_host, self.telemetry_port)
+
+                return self.telemetry_socket
+            else:
+                if not self.socket:
+                    if self.socket_path is not None:
+                        self.socket = self._get_uds_socket(self.socket_path)
+                    else:
+                        self.socket = self._get_udp_socket(self.host, self.port)
 
         return self.socket
 
+    @staticmethod
+    def _get_uds_socket(socket_path):
+        sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
+        sock.connect(socket_path)
+        sock.setblocking(0)
+        return sock
+
+    @staticmethod
+    def _get_udp_socket(host, port):
+        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        sock.connect((host, port))
+        return sock
+
     def open_buffer(self, max_buffer_size=None):
         """
         Open a buffer to send a batch of metrics.
@@ -271,8 +336,8 @@ class DogStatsd(object):
         You can also use this as a context manager.
 
         >>> with DogStatsd() as batch:
-        >>>     batch.gauge('users.online', 123)
-        >>>     batch.gauge('active.connections', 1001)
+        >>>     batch.gauge("users.online", 123)
+        >>>     batch.gauge("active.connections", 1001)
         """
         if max_buffer_size is not None:
             log.warning("The parameter max_buffer_size is now deprecated and is not used anymore")
@@ -292,64 +357,64 @@ class DogStatsd(object):
 
     def gauge(
         self,
-        metric,           # type: Text
-        value,            # type: float
-        tags=None,        # type: Optional[List[str]]
-        sample_rate=None  # type: Optional[float]
+        metric,  # type: Text
+        value,  # type: float
+        tags=None,  # type: Optional[List[str]]
+        sample_rate=None,  # type: Optional[float]
     ):  # type(...) -> None
         """
         Record the value of a gauge, optionally setting a list of tags and a
         sample rate.
 
-        >>> statsd.gauge('users.online', 123)
-        >>> statsd.gauge('active.connections', 1001, tags=["protocol:http"])
+        >>> statsd.gauge("users.online", 123)
+        >>> statsd.gauge("active.connections", 1001, tags=["protocol:http"])
         """
-        return self._report(metric, 'g', value, tags, sample_rate)
+        return self._report(metric, "g", value, tags, sample_rate)
 
     def increment(
         self,
-        metric,             # type: Text
-        value=1,            # type: float
-        tags=None,          # type: Optional[List[str]]
-        sample_rate=None    # type: Optional[float]
+        metric,  # type: Text
+        value=1,  # type: float
+        tags=None,  # type: Optional[List[str]]
+        sample_rate=None,  # type: Optional[float]
     ):  # type: (...) -> None
         """
         Increment a counter, optionally setting a value, tags and a sample
         rate.
 
-        >>> statsd.increment('page.views')
-        >>> statsd.increment('files.transferred', 124)
+        >>> statsd.increment("page.views")
+        >>> statsd.increment("files.transferred", 124)
         """
-        self._report(metric, 'c', value, tags, sample_rate)
+        self._report(metric, "c", value, tags, sample_rate)
 
     def decrement(self, metric, value=1, tags=None, sample_rate=None):
         """
         Decrement a counter, optionally setting a value, tags and a sample
         rate.
 
-        >>> statsd.decrement('files.remaining')
-        >>> statsd.decrement('active.connections', 2)
+        >>> statsd.decrement("files.remaining")
+        >>> statsd.decrement("active.connections", 2)
         """
         metric_value = -value if value else value
-        self._report(metric, 'c', metric_value, tags, sample_rate)
+        self._report(metric, "c", metric_value, tags, sample_rate)
 
     def histogram(self, metric, value, tags=None, sample_rate=None):
         """
         Sample a histogram value, optionally setting tags and a sample rate.
 
-        >>> statsd.histogram('uploaded.file.size', 1445)
-        >>> statsd.histogram('album.photo.count', 26, tags=["gender:female"])
+        >>> statsd.histogram("uploaded.file.size", 1445)
+        >>> statsd.histogram("album.photo.count", 26, tags=["gender:female"])
         """
-        self._report(metric, 'h', value, tags, sample_rate)
+        self._report(metric, "h", value, tags, sample_rate)
 
     def distribution(self, metric, value, tags=None, sample_rate=None):
         """
         Send a global distribution value, optionally setting tags and a sample rate.
 
-        >>> statsd.distribution('uploaded.file.size', 1445)
-        >>> statsd.distribution('album.photo.count', 26, tags=["gender:female"])
+        >>> statsd.distribution("uploaded.file.size", 1445)
+        >>> statsd.distribution("album.photo.count", 26, tags=["gender:female"])
         """
-        self._report(metric, 'd', value, tags, sample_rate)
+        self._report(metric, "d", value, tags, sample_rate)
 
     def timing(self, metric, value, tags=None, sample_rate=None):
         """
@@ -357,7 +422,7 @@ class DogStatsd(object):
 
         >>> statsd.timing("query.response.time", 1234)
         """
-        self._report(metric, 'ms', value, tags, sample_rate)
+        self._report(metric, "ms", value, tags, sample_rate)
 
     def timed(self, metric=None, tags=None, sample_rate=None, use_ms=None):
         """
@@ -368,13 +433,13 @@ class DogStatsd(object):
         manager.
         ::
 
-            @statsd.timed('user.query.time', sample_rate=0.5)
+            @statsd.timed("user.query.time", sample_rate=0.5)
             def get_user(user_id):
                 # Do what you need to ...
                 pass
 
             # Is equivalent to ...
-            with statsd.timed('user.query.time', sample_rate=0.5):
+            with statsd.timed("user.query.time", sample_rate=0.5):
                 # Do what you need to ...
                 pass
 
@@ -383,7 +448,7 @@ class DogStatsd(object):
             try:
                 get_user(user_id)
             finally:
-                statsd.timing('user.query.time', time.time() - start)
+                statsd.timing("user.query.time", time.time() - start)
         """
         return TimedContextManagerDecorator(self, metric, tags, sample_rate, use_ms)
 
@@ -396,13 +461,13 @@ class DogStatsd(object):
         The metric is required as a context manager.
         ::
 
-            @statsd.distributed('user.query.time', sample_rate=0.5)
+            @statsd.distributed("user.query.time", sample_rate=0.5)
             def get_user(user_id):
                 # Do what you need to ...
                 pass
 
             # Is equivalent to ...
-            with statsd.distributed('user.query.time', sample_rate=0.5):
+            with statsd.distributed("user.query.time", sample_rate=0.5):
                 # Do what you need to ...
                 pass
 
@@ -411,7 +476,7 @@ class DogStatsd(object):
             try:
                 get_user(user_id)
             finally:
-                statsd.distribution('user.query.time', time.time() - start)
+                statsd.distribution("user.query.time", time.time() - start)
         """
         return DistributedContextManagerDecorator(self, metric, tags, sample_rate, use_ms)
 
@@ -419,9 +484,9 @@ class DogStatsd(object):
         """
         Sample a set value.
 
-        >>> statsd.set('visitors.uniques', 999)
+        >>> statsd.set("visitors.uniques", 999)
         """
-        self._report(metric, 's', value, tags, sample_rate)
+        self._report(metric, "s", value, tags, sample_rate)
 
     def close_socket(self):
         """
@@ -434,6 +499,13 @@ class DogStatsd(object):
                 log.error("Unexpected error: %s", str(e))
             self.socket = None
 
+        if self.telemetry_socket:
+            try:
+                self.telemetry_socket.close()
+            except OSError as e:
+                log.error("Unexpected error: %s", str(e))
+            self.telemetry_socket = None
+
     def _serialize_metric(self, metric, metric_type, value, tags, sample_rate=1):
         # Create/format the metric packet
         return "%s%s:%s|%s%s%s" % (
@@ -485,24 +557,26 @@ class DogStatsd(object):
 
     def _flush_telemetry(self):
         telemetry_tags = ",".join(self._add_constant_tags(self._client_tags))
-        return "\n".join((
-            "datadog.dogstatsd.client.metrics:%s|c|#%s" % (self.metrics_count, telemetry_tags),
-            "datadog.dogstatsd.client.events:%s|c|#%s" % (self.events_count, telemetry_tags),
-            "datadog.dogstatsd.client.service_checks:%s|c|#%s" % (self.service_checks_count, telemetry_tags),
-            "datadog.dogstatsd.client.bytes_sent:%s|c|#%s" % (self.bytes_sent, telemetry_tags),
-            "datadog.dogstatsd.client.bytes_dropped:%s|c|#%s" % (self.bytes_dropped, telemetry_tags),
-            "datadog.dogstatsd.client.packets_sent:%s|c|#%s" % (self.packets_sent, telemetry_tags),
-            "datadog.dogstatsd.client.packets_dropped:%s|c|#%s" % (self.packets_dropped, telemetry_tags),
-        ))
+        return "\n".join(
+            (
+                "datadog.dogstatsd.client.metrics:%s|c|#%s" % (self.metrics_count, telemetry_tags),
+                "datadog.dogstatsd.client.events:%s|c|#%s" % (self.events_count, telemetry_tags),
+                "datadog.dogstatsd.client.service_checks:%s|c|#%s" % (self.service_checks_count, telemetry_tags),
+                "datadog.dogstatsd.client.bytes_sent:%s|c|#%s" % (self.bytes_sent, telemetry_tags),
+                "datadog.dogstatsd.client.bytes_dropped:%s|c|#%s" % (self.bytes_dropped, telemetry_tags),
+                "datadog.dogstatsd.client.packets_sent:%s|c|#%s" % (self.packets_sent, telemetry_tags),
+                "datadog.dogstatsd.client.packets_dropped:%s|c|#%s" % (self.packets_dropped, telemetry_tags),
+            )
+        )
 
     def _is_telemetry_flush_time(self):
         return self._telemetry and self._last_flush_time + self._telemetry_flush_interval < time.time()
 
     def _send_to_server(self, packet):
-        self._xmit_packet(packet, self._telemetry)
+        self._xmit_packet(packet, False)
         if self._is_telemetry_flush_time():
             telemetry = self._flush_telemetry()
-            if self._xmit_packet(telemetry, False):
+            if self._xmit_packet(telemetry, True):
                 self._reset_telemetry()
                 self.packets_sent += 1
                 self.bytes_sent += len(telemetry)
@@ -512,29 +586,42 @@ class DogStatsd(object):
                 self.bytes_dropped += len(telemetry)
                 self.packets_dropped += 1
 
-    def _xmit_packet(self, packet, telemetry):
+    def _xmit_packet(self, packet, is_telemetry):
         try:
-            # If set, use socket directly
-            (self.socket or self.get_socket()).send(packet.encode(self.encoding))
-            if telemetry:
+            if is_telemetry and self._dedicated_telemetry_destination():
+                mysocket = self.telemetry_socket or self.get_socket(telemetry=True)
+            else:
+                # If set, use socket directly
+                mysocket = self.socket or self.get_socket()
+
+            mysocket.send(packet.encode(self.encoding))
+
+            if not is_telemetry and self._telemetry:
                 self.packets_sent += 1
                 self.bytes_sent += len(packet)
+
             return True
         except socket.timeout:
             # dogstatsd is overflowing, drop the packets (mimicks the UDP behaviour)
             pass
         except (socket.herror, socket.gaierror) as se:
-            log.warning("Error submitting packet: {}, dropping the packet and closing the socket".format(se))
+            log.warning(
+                "Error submitting packet: %s, dropping the packet and closing the socket",
+                se,
+            )
             self.close_socket()
         except socket.error as se:
             if se.errno == errno.EAGAIN:
-                log.warning("Socket send would block: {}, dropping the packet".format(se))
+                log.debug("Socket send would block: %s, dropping the packet", se)
             else:
-                log.warning("Error submitting packet: {}, dropping the packet and closing the socket".format(se))
+                log.warning(
+                    "Error submitting packet: %s, dropping the packet and closing the socket",
+                    se,
+                )
                 self.close_socket()
         except Exception as e:
             log.error("Unexpected error: %s", str(e))
-        if telemetry:
+        if not is_telemetry and self._telemetry:
             self.bytes_dropped += len(packet)
             self.packets_dropped += 1
         return False
@@ -544,7 +631,7 @@ class DogStatsd(object):
             self._flush_buffer()
         self.buffer.append(packet)
         # Update the current buffer length, including line break to anticipate the final packet size
-        self._current_buffer_total_size += (len(packet) + 1)
+        self._current_buffer_total_size += len(packet) + 1
 
     def _should_flush(self, length_to_be_added):
         if self._current_buffer_total_size + length_to_be_added > self._max_payload_size:
@@ -557,20 +644,29 @@ class DogStatsd(object):
         self.buffer = []
 
     def _escape_event_content(self, string):
-        return string.replace('\n', '\\n')
+        return string.replace("\n", "\\n")
 
     def _escape_service_check_message(self, string):
-        return string.replace('\n', '\\n').replace('m:', 'm\\:')
+        return string.replace("\n", "\\n").replace("m:", "m\\:")
 
-    def event(self, title, text, alert_type=None, aggregation_key=None,
-              source_type_name=None, date_happened=None, priority=None,
-              tags=None, hostname=None):
+    def event(
+        self,
+        title,
+        text,
+        alert_type=None,
+        aggregation_key=None,
+        source_type_name=None,
+        date_happened=None,
+        priority=None,
+        tags=None,
+        hostname=None,
+    ):
         """
         Send an event. Attributes are the same as the Event API.
             http://docs.datadoghq.com/api/
 
-        >>> statsd.event('Man down!', 'This server needs assistance.')
-        >>> statsd.event('The web server restarted', 'The web server is up again', alert_type='success')  # NOQA
+        >>> statsd.event("Man down!", "This server needs assistance.")
+        >>> statsd.event("The web server restarted", "The web server is up again", alert_type="success")  # NOQA
         """
         title = self._escape_event_content(title)
         text = self._escape_event_content(text)
@@ -578,52 +674,50 @@ class DogStatsd(object):
         # Append all client level tags to every event
         tags = self._add_constant_tags(tags)
 
-        string = u'_e{%d,%d}:%s|%s' % (len(title), len(text), title, text)
+        string = u"_e{%d,%d}:%s|%s" % (len(title), len(text), title, text)
         if date_happened:
-            string = '%s|d:%d' % (string, date_happened)
+            string = "%s|d:%d" % (string, date_happened)
         if hostname:
-            string = '%s|h:%s' % (string, hostname)
+            string = "%s|h:%s" % (string, hostname)
         if aggregation_key:
-            string = '%s|k:%s' % (string, aggregation_key)
+            string = "%s|k:%s" % (string, aggregation_key)
         if priority:
-            string = '%s|p:%s' % (string, priority)
+            string = "%s|p:%s" % (string, priority)
         if source_type_name:
-            string = '%s|s:%s' % (string, source_type_name)
+            string = "%s|s:%s" % (string, source_type_name)
         if alert_type:
-            string = '%s|t:%s' % (string, alert_type)
+            string = "%s|t:%s" % (string, alert_type)
         if tags:
-            string = '%s|#%s' % (string, ','.join(tags))
+            string = "%s|#%s" % (string, ",".join(tags))
 
         if len(string) > 8 * 1024:
-            raise Exception(u'Event "%s" payload is too big (more than 8KB), '
-                            'event discarded' % title)
+            raise Exception(u'Event "%s" payload is too big (more than 8KB), ' "event discarded" % title)
 
         if self._telemetry:
             self.events_count += 1
         self._send(string)
 
-    def service_check(self, check_name, status, tags=None, timestamp=None,
-                      hostname=None, message=None):
+    def service_check(self, check_name, status, tags=None, timestamp=None, hostname=None, message=None):
         """
         Send a service check run.
 
-        >>> statsd.service_check('my_service.check_name', DogStatsd.WARNING)
+        >>> statsd.service_check("my_service.check_name", DogStatsd.WARNING)
         """
-        message = self._escape_service_check_message(message) if message is not None else ''
+        message = self._escape_service_check_message(message) if message is not None else ""
 
-        string = u'_sc|{0}|{1}'.format(check_name, status)
+        string = u"_sc|{0}|{1}".format(check_name, status)
 
         # Append all client level tags to every status check
         tags = self._add_constant_tags(tags)
 
         if timestamp:
-            string = u'{0}|d:{1}'.format(string, timestamp)
+            string = u"{0}|d:{1}".format(string, timestamp)
         if hostname:
-            string = u'{0}|h:{1}'.format(string, hostname)
+            string = u"{0}|h:{1}".format(string, hostname)
         if tags:
-            string = u'{0}|#{1}'.format(string, ','.join(tags))
+            string = u"{0}|#{1}".format(string, ",".join(tags))
         if message:
-            string = u'{0}|m:{1}'.format(string, message)
+            string = u"{0}|m:{1}".format(string, message)
 
         if self._telemetry:
             self.service_checks_count += 1
