@@ -12,7 +12,7 @@ class MetricType(object):
 
 
 class MonitorType(object):
-    SERVICE_CHECK = 'service check'
-    METRIC_ALERT = 'metric alert'
-    QUERY_ALERT = 'query alert'
+    SERVICE_CHECK = "service check"
+    METRIC_ALERT = "metric alert"
+    QUERY_ALERT = "query alert"
     ALL = (SERVICE_CHECK, METRIC_ALERT, QUERY_ALERT)
