@@ -84,19 +84,26 @@ class OverflownSocket(FakeSocket):
 def telemetry_metrics(metrics=1, events=0, service_checks=0, bytes_sent=0, bytes_dropped=0, packets_sent=1, packets_dropped=0, transport="udp", tags=""):
     tags = "," + tags if tags else ""
 
-    return "datadog.dogstatsd.client.metrics:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(metrics, version, transport, tags) \
-        + "datadog.dogstatsd.client.events:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(events, version, transport, tags) \
-        + "datadog.dogstatsd.client.service_checks:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(service_checks, version, transport, tags) \
-        + "datadog.dogstatsd.client.bytes_sent:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(bytes_sent, version, transport, tags) \
-        + "datadog.dogstatsd.client.bytes_dropped:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(bytes_dropped, version, transport, tags) \
-        + "datadog.dogstatsd.client.packets_sent:{}|c|#client:py,client_version:{},client_transport:{}{}\n".format(packets_sent, version, transport, tags) \
-        + "datadog.dogstatsd.client.packets_dropped:{}|c|#client:py,client_version:{},client_transport:{}{}".format(packets_dropped, version, transport, tags)
+    return "\n".join([
+        "datadog.dogstatsd.client.metrics:{}|c|#client:py,client_version:{},client_transport:{}{}".format(metrics, version, transport, tags),
+        "datadog.dogstatsd.client.events:{}|c|#client:py,client_version:{},client_transport:{}{}".format(events, version, transport, tags),
+        "datadog.dogstatsd.client.service_checks:{}|c|#client:py,client_version:{},client_transport:{}{}".format(service_checks, version, transport, tags),
+        "datadog.dogstatsd.client.bytes_sent:{}|c|#client:py,client_version:{},client_transport:{}{}".format(bytes_sent, version, transport, tags),
+        "datadog.dogstatsd.client.bytes_dropped:{}|c|#client:py,client_version:{},client_transport:{}{}".format(bytes_dropped, version, transport, tags),
+        "datadog.dogstatsd.client.packets_sent:{}|c|#client:py,client_version:{},client_transport:{}{}".format(packets_sent, version, transport, tags),
+        "datadog.dogstatsd.client.packets_dropped:{}|c|#client:py,client_version:{},client_transport:{}{}".format(packets_dropped, version, transport, tags)
+    ])
+
 
 def assert_equal_telemetry(expected_payload, actual_payload, telemetry=None):
     if telemetry is None:
         telemetry = telemetry_metrics(bytes_sent=len(expected_payload))
-    expected_payload += "\n"
-    expected_payload += telemetry
+
+    if expected_payload:
+        expected_payload = "\n".join([expected_payload, telemetry])
+    else:
+        expected_payload = telemetry
+
     return assert_equal(expected_payload, actual_payload)
 
 class TestDogStatsd(unittest.TestCase):
@@ -112,7 +119,7 @@ class TestDogStatsd(unittest.TestCase):
         # Mock the proc filesystem
         route_data = load_fixtures('route')
         self._procfs_mock = patch('datadog.util.compat.builtins.open', mock_open())
-        self._procfs_mock.__enter__().return_value.readlines.return_value = route_data.split("\n")
+        self._procfs_mock.start().return_value.readlines.return_value = route_data.split("\n")
 
     #def setup_method(self, method):
     #    self.statsd._reset_telemetry()
@@ -121,7 +128,7 @@ class TestDogStatsd(unittest.TestCase):
         """
         Unmock the proc filesystem.
         """
-        self._procfs_mock.__exit__()
+        self._procfs_mock.stop()
 
     def recv(self, n=1):
         packets = []
@@ -298,7 +305,7 @@ class TestDogStatsd(unittest.TestCase):
             'my_check.name', self.statsd.WARNING,
             tags=['key1:val1', 'key2:val2'], timestamp=now,
             hostname='i-abcd1234', message=u"♬ †øU \n†øU ¥ºu|m: T0µ ♪")
-        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#key1:val1,key2:val2|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\: T0µ ♪")
+        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#key1:val1,key2:val2|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\\: T0µ ♪")
         assert_equal_telemetry(check, self.recv(2), telemetry=telemetry_metrics(metrics=0, service_checks=1, bytes_sent=len(check)))
 
     def test_service_check_constant_tags(self):
@@ -308,7 +315,7 @@ class TestDogStatsd(unittest.TestCase):
             'my_check.name', self.statsd.WARNING,
             timestamp=now,
             hostname='i-abcd1234', message=u"♬ †øU \n†øU ¥ºu|m: T0µ ♪")
-        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#bar:baz,foo|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\: T0µ ♪")
+        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#bar:baz,foo|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\\: T0µ ♪")
         assert_equal_telemetry(check, self.recv(2),
             telemetry=telemetry_metrics(metrics=0, service_checks=1, tags="bar:baz,foo", bytes_sent=len(check)))
 
@@ -318,7 +325,7 @@ class TestDogStatsd(unittest.TestCase):
             'my_check.name', self.statsd.WARNING,
             tags=['key1:val1', 'key2:val2'], timestamp=now,
             hostname='i-abcd1234', message=u"♬ †øU \n†øU ¥ºu|m: T0µ ♪")
-        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#key1:val1,key2:val2,bar:baz,foo|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\: T0µ ♪")
+        check = u'_sc|my_check.name|{0}|d:{1}|h:i-abcd1234|#key1:val1,key2:val2,bar:baz,foo|m:{2}'.format(self.statsd.WARNING, now, u"♬ †øU \\n†øU ¥ºu|m\\: T0µ ♪")
         assert_equal_telemetry(check, self.recv(2),
             telemetry=telemetry_metrics(metrics=0, service_checks=1, tags="bar:baz,foo", bytes_sent=len(check)))
 
@@ -368,7 +375,8 @@ class TestDogStatsd(unittest.TestCase):
             self.statsd.gauge('no error', 1)
             mock_log.error.assert_not_called()
             mock_log.warning.assert_called_once_with(
-                "Error submitting packet: Socket error, dropping the packet and closing the socket"
+                "Error submitting packet: %s, dropping the packet and closing the socket",
+                mock.ANY,
             )
 
     def test_socket_overflown(self):
@@ -376,8 +384,8 @@ class TestDogStatsd(unittest.TestCase):
         with mock.patch("datadog.dogstatsd.base.log") as mock_log:
             self.statsd.gauge('no error', 1)
             mock_log.error.assert_not_called()
-            c = [call("Socket send would block: Socket error, dropping the packet")]
-            mock_log.warning.assert_has_calls(c * 2)
+            c = [call("Socket send would block: %s, dropping the packet", mock.ANY)]
+            mock_log.debug.assert_has_calls(c * 2)
 
     def test_distributed(self):
         """
@@ -543,15 +551,18 @@ class TestDogStatsd(unittest.TestCase):
         """
         import asyncio
 
-        @self.statsd.timed('timed.test')
-        @asyncio.coroutine
-        def print_foo():
-            """docstring"""
-            time.sleep(0.5)
-            print("foo")
+        source= """
+@self.statsd.timed('timed.test')
+async def print_foo():
+    "docstring"
+    import time
+    time.sleep(0.5)
+    print("foo")
+        """
+        exec(source, {}, locals())
 
         loop = asyncio.get_event_loop()
-        loop.run_until_complete(print_foo())
+        loop.run_until_complete(locals()['print_foo']())
         loop.close()
 
         # Assert
@@ -719,6 +730,33 @@ class TestDogStatsd(unittest.TestCase):
         # assert that _last_flush_time has been updated
         assert t1 < statsd._last_flush_time
 
+    def test_telemetry_flush_interval_alternate_destination(self):
+        statsd = DogStatsd(telemetry_host='foo')
+        fake_socket = FakeSocket()
+        statsd.socket = fake_socket
+        fake_telemetry_socket = FakeSocket()
+        statsd.telemetry_socket = fake_telemetry_socket
+
+        assert statsd.telemetry_host != None
+        assert statsd.telemetry_port != None
+        assert statsd._dedicated_telemetry_destination()
+
+        # set the last flush time in the future to be sure we won't flush
+        statsd._last_flush_time = time.time() + statsd._telemetry_flush_interval
+        statsd.gauge('gauge', 123.4)
+
+        assert_equal('gauge:123.4|g', fake_socket.recv())
+
+        t1 = time.time()
+        # setting the last flush time in the past to trigger a telemetry flush
+        statsd._last_flush_time = t1 - statsd._telemetry_flush_interval - 1
+        statsd.gauge('gauge', 123.4)
+
+        assert_equal('gauge:123.4|g', fake_socket.recv())
+        assert_equal_telemetry('', fake_telemetry_socket.recv(), telemetry=telemetry_metrics(metrics=2, bytes_sent=13*2, packets_sent=2))
+        # assert that _last_flush_time has been updated
+        assert t1 < statsd._last_flush_time
+
     def test_telemetry_flush_interval_batch(self):
         statsd = DogStatsd()
 
@@ -888,9 +926,10 @@ class TestDogStatsd(unittest.TestCase):
             # Make call with no tags passed; only the globally configured tags will be used.
             global_tags_str = ','.join([t for t in global_tags])
             statsd.gauge('gt', 123.4)
+
             # Protect against the no tags case.
             metric = 'gt:123.4|g|#{}'.format(global_tags_str) if global_tags_str else 'gt:123.4|g'
-            assert_equal(metric, statsd.socket.recv())
+            assert_equal( metric, statsd.socket.recv())
             assert_equal(telemetry_metrics(tags=global_tags_str, bytes_sent=len(metric)), statsd.socket.recv())
             statsd._reset_telemetry()
 
